package com.dcsoft.system.kq.service;

import com.dcsoft.system.kq.domain.KqAdjust;

import java.util.List;

/**
 * 出勤调整Service接口
 *
 * @author nichun
 * @date 2023-06-09
 */
public interface IKqAdjustService
{
    /**
     * 查询出勤调整
     *
     * @param adjustId 出勤调整主键
     * @return 出勤调整
     */
    public KqAdjust selectKqAdjustByAdjustId(Long adjustId);

    /**
     * 查询出勤调整列表
     *
     * @param kqAdjust 出勤调整
     * @return 出勤调整集合
     */
    public List<KqAdjust> selectKqAdjustList(KqAdjust kqAdjust);

    /**
     * 新增出勤调整
     *
     * @param kqAdjust 出勤调整
     * @return 结果
     */
    public int insertKqAdjust(KqAdjust kqAdjust);

    /**
     * 修改出勤调整
     *
     * @param kqAdjust 出勤调整
     * @return 结果
     */
    public int updateKqAdjust(KqAdjust kqAdjust);

    /**
     * 批量删除出勤调整
     *
     * @param adjustIds 需要删除的出勤调整主键集合
     * @return 结果
     */
    public int deleteKqAdjustByAdjustIds(Long[] adjustIds);

    /**
     * 删除出勤调整信息
     *
     * @param adjustId 出勤调整主键
     * @return 结果
     */
    public int deleteKqAdjustByAdjustId(Long adjustId);

    String importkqAdjust(List<KqAdjust> userList, boolean updateSupport, String operName);
}
